@@ -1,11 +1,12 @@
 import json
 import os
 import warnings
-from enum import Enum, unique
+from enum import Enum
 from pathlib import Path
 from typing import Dict, Optional
 
 import requests
+from packaging import version
 from pydantic import BaseModel
 from pydantic.class_validators import validator
 from pydantic.types import UUID4
@@ -13,6 +14,7 @@ from requests.exceptions import ConnectionError as ReqConnectionError
 
 from dataquality import __version__ as dq_version
 from dataquality.exceptions import GalileoException
+from dataquality.schemas.route import Route
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.helpers import galileo_disabled
 
@@ -45,14 +47,8 @@ class ConfigData(str, Enum):
     DEFAULT_GALILEO_CONFIG_FILE = f"{DEFAULT_GALILEO_CONFIG_DIR}/config.json"
 
 
-@unique
-class AuthMethod(str, Enum):
-    email = "email"
-
-
 class Config(BaseModel):
     api_url: str
-    auth_method: AuthMethod = AuthMethod.email
     token: Optional[str] = None
     current_user: Optional[str] = None
     current_project_id: Optional[UUID4] = None
@@ -86,7 +82,9 @@ def set_platform_urls(console_url_str: str) -> None:
     if url_is_localhost(console_url_str):
         os.environ[GalileoConfigVars.API_URL] = "http://localhost:8088"
     else:
-        api_url = console_url_str.replace("console.", "api.").rstrip("/")
+        # some urls are set up as "console-xxx.domain instead of console.xxx.domain
+        sfx = "." if "console." in console_url_str else "-"
+        api_url = console_url_str.replace(f"console{sfx}", f"api{sfx}").rstrip("/")
         api_url = f"https://{api_url}" if not api_url.startswith("http") else api_url
         api_url = api_url.replace("http://", "https://")
         _validate_api_url(console_url_str, api_url)
@@ -104,13 +102,35 @@ def _validate_api_url(console_url: str, api_url: str) -> None:
     )
     url = f"https://{api_url}" if not api_url.startswith("http") else api_url
     try:
-        r = requests.get(f"{url}/healthcheck")
+        r = requests.get(f"{url}/{Route.healthcheck}")
         if not r.ok:
             raise GalileoException(err_detail.format(err=r.text)) from None
     except (ReqConnectionError, ConnectionError) as e:
         raise GalileoException(err_detail.format(err=str(e))) from None
 
 
+def _check_dq_version() -> None:
+    """Check that user is running valid version of DQ client
+    Pings backend to check minimum DQ version requirements.
+    """
+    r = requests.get(f"{os.environ[GalileoConfigVars.API_URL]}/{Route.healthcheck}/dq")
+    if not r.ok:
+        if r.status_code == 404:
+            # We don't want to raise error if api doesn't have dq healthcheck yet
+            return
+        raise GalileoException(r.text) from None
+
+    min_version = r.json()["minimum_dq_version"]
+    if version.parse(dq_version) < version.parse(min_version):
+        msg = (
+            f"⚠️ You are running an old version of dataquality. Please upgrade to "
+            f"version {min_version} or higher (you are running {dq_version})."
+            f"  `pip install dataquality --upgrade`"
+        )
+        # The user is running an incompatible DQ version, must upgrade
+        raise GalileoException(msg)
+
+
 def _check_console_url() -> None:
     """Checks for user setting of GALILEO_CONSOLE_URL instead of
 
@@ -119,7 +139,11 @@ def _check_console_url() -> None:
     """
     console_url = os.getenv(GalileoConfigVars.CONSOLE_URL)
     if console_url:
-        if "console." not in console_url and not url_is_localhost(console_url):
+        if (
+            "console." not in console_url
+            and "console-" not in console_url
+            and not url_is_localhost(console_url)
+        ):
             warnings.warn(
                 f"It seems your GALILEO_CONSOLE_URL ({console_url}) is invalid. "
                 f"Your console URL should have 'console.' in the url. Ignoring"
